==> sbe-all-1.33.0-sources.jar: uk/co/real_logic/sbe/generation/csharp/CSharp.java <==
/*
 * Copyright 2013-2024 Real Logic Limited.
 * Copyright 2017 MarketFactory Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package uk.co.real_logic.sbe.generation.csharp;

import uk.co.real_logic.sbe.generation.CodeGenerator;
import uk.co.real_logic.sbe.generation.TargetCodeGenerator;
import uk.co.real_logic.sbe.generation.TargetCodeGeneratorLoader;
import uk.co.real_logic.sbe.ir.Ir;

/**
 * {@link CodeGenerator} factory for the CSharp target programming language.
 */
public class CSharp implements TargetCodeGenerator
{
    private static final boolean GENERATE_DTOS = Boolean.getBoolean("sbe.csharp.generate.dtos");

    /**
     * {@inheritDoc}
     */
    public CodeGenerator newInstance(final Ir ir, final String outputDir)
    {
        final CSharpGenerator flyweightGenerator = new CSharpGenerator(
            ir,
            TargetCodeGeneratorLoader.precedenceChecks(),
            new CSharpNamespaceOutputManager(outputDir, ir.applicableNamespace()));

        if (GENERATE_DTOS)
        {
            final CSharpDtoGenerator dtoGenerator =
                new CSharpDtoGenerator(ir, new CSharpNamespaceOutputManager(outputDir, ir.applicableNamespace()));

            return () ->
            {
                flyweightGenerator.generate();
                dtoGenerator.generate();
            };
        }

        return flyweightGenerator;
    }
}

==> sbe-all-1.36.2-sources.jar: uk/co/real_logic/sbe/generation/csharp/CSharp.java <==
/*
 * Copyright 2013-2025 Real Logic Limited.
 * Copyright 2017 MarketFactory Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package uk.co.real_logic.sbe.generation.csharp;

import uk.co.real_logic.sbe.generation.CodeGenerator;
import uk.co.real_logic.sbe.generation.TargetCodeGenerator;
import uk.co.real_logic.sbe.generation.TargetCodeGeneratorLoader;
import uk.co.real_logic.sbe.ir.Ir;

import static uk.co.real_logic.sbe.SbeTool.TYPES_PACKAGE_OVERRIDE;

/**
 * {@link CodeGenerator} factory for the CSharp target programming language.
 */
public class CSharp implements TargetCodeGenerator
{
    private static final boolean GENERATE_DTOS = Boolean.getBoolean("sbe.csharp.generate.dtos");

    /**
     * {@inheritDoc}
     */
    public CodeGenerator newInstance(final Ir ir, final String outputDir)
    {
        final boolean shouldSupportTypesPackageNames = Boolean.getBoolean(TYPES_PACKAGE_OVERRIDE);
        final CSharpGenerator flyweightGenerator = new CSharpGenerator(
            ir,
            TargetCodeGeneratorLoader.precedenceChecks(),
            shouldSupportTypesPackageNames,
            new CSharpNamespaceOutputManager(outputDir, ir.applicableNamespace()));

        if (GENERATE_DTOS)
        {
            final CSharpDtoGenerator dtoGenerator = new CSharpDtoGenerator(
                ir,
                shouldSupportTypesPackageNames,
                new CSharpNamespaceOutputManager(outputDir, ir.applicableNamespace()));

            return () ->
            {
                flyweightGenerator.generate();
                dtoGenerator.generate();
            };
        }

        return flyweightGenerator;
    }
}
